@@ -15,7 +15,7 @@ def df_from_s3_csv(s3_client, bucket, key):
     :return: pandas dataframe
     """
     obj = s3_client.get_object(Bucket=bucket, Key=key)
-    return pd.read_csv(obj['Body'])
+    return pd.read_csv(obj['Body'], sep=',',  index_col=0)
 
 
 def df_to_s3_csv(s3_client, bucket, key, df):
@@ -85,7 +85,7 @@ def metric_node(
     :param region_name: str
     :param to_bucket: str
     :param to_key: str
-    :param queue_name:
+    :param queue_name:  CURRENTLY OVERRIDDEN AS IT FAILS
     :param func: function that takes a pandas df and returns a pandas df
     :return:
     """
@@ -117,6 +117,8 @@ def metric_node(
         'completed_stations': completed_stations
     }
 
+    # override queue name until we can find a way to grant access to the queue
+    queue_name = ""
     msg = send_sqs_message(to_sqs_url, queue_name, message, region_name)
 
     if msg is not None:
@@ -124,5 +126,6 @@ def metric_node(
 
     return {
         'statusCode': 200,
-        'body': message
+        'body': message,
+        'cols': list(finished_df.columns[:min(len(finished_df.columns), 5)])
     }
